/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'id', {
	button: 'Masukkan potongan kode',
	codeContents: 'Konten kode',
	emptySnippetError: 'Potongan kode tidak boleh kosong',
	language: 'Bahasa',
	title: 'Potongan kode',
	pathName: 'potongan kode'
} );
